==> currency_cloud-1.0.0.tar.gz: lib/src/api/messages/beneficiary.dart <==
part of '../../../messages.dart';

class CreateBeneficiary extends Encoding {
  final String name;
  final String bankAccountHolderName;
  final String bankCountry;

  /// Currency code (ISO 4217)
  final String currency;
  final String email;
  final String beneficiaryAddress;
  final String beneficiaryCountry;
  final String accountNumber;
  final RoutingCodeType routingCodeType1;
  final String routingCodeValue1;
  final RoutingCodeType routingCodeType2;
  final String routingCodeValue2;
  final String bicSwift;
  final String iban;
  final bool defaultBeneficiary;
  final String bankAddress;
  final String bankName;
  final BankAccountType bankAccountType;
  final EntityType beneficiaryEntityType;
  final String beneficiaryCompanyName;
  final String beneficiaryFirstName;
  final String beneficiaryLastName;
  final String beneficiaryCity;
  final String beneficiaryPostcode;
  final String beneficiaryStateOrProvince;
  final String beneficiaryDateOfBirth;
  final EntityType beneficiaryIdentificationType;
  final String beneficiaryIdentificationValue;
  final List<PaymentType> paymentTypes;
  final String onBehalfOf;

  CreateBeneficiary({
    @required this.name,
    @required this.bankAccountHolderName,
    @required this.bankCountry,
    @required this.currency,
    this.email,
    this.beneficiaryAddress,
    this.beneficiaryCountry,
    this.accountNumber,
    this.routingCodeType1,
    this.routingCodeValue1,
    this.routingCodeType2,
    this.routingCodeValue2,
    this.bicSwift,
    this.iban,
    this.defaultBeneficiary,
    this.bankAddress,
    this.bankName,
    this.bankAccountType,
    this.beneficiaryEntityType,
    this.beneficiaryCompanyName,
    this.beneficiaryFirstName,
    this.beneficiaryLastName,
    this.beneficiaryCity,
    this.beneficiaryPostcode,
    this.beneficiaryStateOrProvince,
    this.beneficiaryDateOfBirth,
    this.beneficiaryIdentificationType,
    this.beneficiaryIdentificationValue,
    this.paymentTypes,
    this.onBehalfOf,
  });

  @override
  void encode(KeyedArchive object) {
    object
      ..encode('name', name)
      ..encode('bank_account_holder_name', bankAccountHolderName)
      ..encode('bank_country', bankCountry)
      ..encode('currency', currency)
      ..encode('email', email)
      ..encode('beneficiary_address', beneficiaryAddress)
      ..encode('beneficiary_country', beneficiaryCountry)
      ..encode('account_number', accountNumber)
      ..encode('routing_code_type_1', routingCodeType1?.id)
      ..encode('routing_code_value_1', routingCodeValue1)
      ..encode('routing_code_type_2', routingCodeType2?.id)
      ..encode('routing_code_value_2', routingCodeValue2)
      ..encode('bic_swift', bicSwift)
      ..encode('iban', iban)
      ..encode('default_beneficiary', defaultBeneficiary)
      ..encode('bank_address', bankAddress)
      ..encode('bank_name', bankName)
      ..encode('bank_account_type', bankAccountType?.id)
      ..encode('beneficiary_entity_type', beneficiaryEntityType?.id)
      ..encode('beneficiary_company_name', beneficiaryCompanyName)
      ..encode('beneficiary_first_name', beneficiaryFirstName)
      ..encode('beneficiary_last_name', beneficiaryLastName)
      ..encode('beneficiary_city', beneficiaryCity)
      ..encode('beneficiary_postcode', beneficiaryPostcode)
      ..encode('beneficiary_state_or_province', beneficiaryStateOrProvince)
      ..encode('beneficiary_date_of_birth', beneficiaryDateOfBirth)
      ..encode('beneficiary_identification_type', beneficiaryIdentificationType?.id)
      ..encode('beneficiary_identification_value', beneficiaryIdentificationValue)
      ..encode('payment_types', paymentTypes?.map((v) => v.id)?.toList())
      ..encode('on_behalf_of', onBehalfOf);
  }
}

class Beneficiary extends Decoding {
  String id;
  String bankAccountHolderName;
  String name;
  String email;
  List<PaymentType> paymentTypes;
  List<String> beneficiaryAddress;
  String beneficiaryCountry;
  EntityType beneficiaryEntityType;
  String beneficiaryCompanyName;
  String beneficiaryFirstName;
  String beneficiaryLastName;
  String beneficiaryCity;
  String beneficiaryPostcode;
  String beneficiaryStateOrProvince;
  String beneficiaryDateOfBirth;
  EntityType beneficiaryIdentificationType;
  String beneficiaryIdentificationValue;
  String bankCountry;
  String bankName;
  List<String> bankAddress;
  BankAccountType bankAccountType;
  String onBehalfOf;

  /// Currency code (ISO 4217)
  String currency;
  String accountNumber;
  RoutingCodeType routingCodeType1;
  String routingCodeValue1;
  RoutingCodeType routingCodeType2;
  String routingCodeValue2;
  String bicSwift;
  String iban;
  bool defaultBeneficiary;
  String creatorContactId;
  String beneficiaryExternalReference;
  DateTime createdAt;
  DateTime updatedAt;

  @override
  void decode(KeyedArchive object) {
    super.decode(object);
    id = object.decode('id');
    bankAccountHolderName = object.decode('bank_account_holder_name');
    name = object.decode('name');
    email = object.decode('email');
    paymentTypes = object
        .decode<ListArchive>('payment_types')
        .cast<String>()
        .map((value) => PaymentType.fromString(value))
        .toList();
    beneficiaryAddress = object.decode<ListArchive>('beneficiary_address').cast<String>();
    beneficiaryCountry = object.decode('beneficiary_country');
    beneficiaryEntityType = EntityType.fromString(object.decode('beneficiary_entity_type'));
    beneficiaryCompanyName = object.decode('beneficiary_company_name');
    beneficiaryFirstName = object.decode('beneficiary_first_name');
    beneficiaryLastName = object.decode('beneficiary_last_name');
    beneficiaryCity = object.decode('beneficiary_city');
    beneficiaryPostcode = object.decode('beneficiary_postcode');
    beneficiaryStateOrProvince = object.decode('beneficiary_state_or_province');
    beneficiaryDateOfBirth = object.decode('beneficiary_date_of_birth');
    beneficiaryIdentificationType = EntityType.fromString(object.decode('beneficiary_identification_type'));
    beneficiaryIdentificationValue = object.decode('beneficiary_identification_value');
    bankCountry = object.decode('bank_country');
    bankName = object.decode('bank_name');
    bankAccountType = BankAccountType.fromString(object.decode('bank_account_type'));
    currency = object.decode('currency');
    accountNumber = object.decode('account_number');
    routingCodeType1 = RoutingCodeType.fromString(object.decode('routing_code_type_1'));
    routingCodeValue1 = object.decode('routing_code_value_1');
    routingCodeType2 = RoutingCodeType.fromString(object.decode('routing_code_type_2'));
    routingCodeValue2 = object.decode('routing_code_value_2');
    bicSwift = object.decode('bic_swift');
    iban = object.decode('iban');
    creatorContactId = object.decode('creator_contact_id');
    defaultBeneficiary = boolParse(object.decode('default_beneficiary'));
    bankAddress = object.decode<ListArchive>('bank_address').cast<String>();
    createdAt = dateTimeParse(object.decode('created_at'));
    updatedAt = dateTimeParse(object.decode('updated_at'));
  }

  String toJson() {
    final archive = KeyedArchive.archive(this);
    return jsonEncode(archive);
  }
}

==> currency_cloud-1.0.1.tar.gz: lib/src/api/messages/beneficiary.dart <==
part of '../../../messages.dart';

@JsonSerializable(fieldRename: FieldRename.snake, includeIfNull: false)
class CreateBeneficiary {
  final String name;
  final String bankAccountHolderName;
  final String bankCountry;

  /// Currency code (ISO 4217)
  final String currency;
  final String email;
  final String beneficiaryAddress;
  final String beneficiaryCountry;
  final String accountNumber;
  final RoutingCodeType routingCodeType1;
  final String routingCodeValue1;
  final RoutingCodeType routingCodeType2;
  final String routingCodeValue2;
  final String bicSwift;
  final String iban;
  @JsonKey(toJson: boolToJson, fromJson: boolFromJson)
  final bool defaultBeneficiary;
  final String bankAddress;
  final String bankName;
  final BankAccountType bankAccountType;
  final EntityType beneficiaryEntityType;
  final String beneficiaryCompanyName;
  final String beneficiaryFirstName;
  final String beneficiaryLastName;
  final String beneficiaryCity;
  final String beneficiaryPostcode;
  final String beneficiaryStateOrProvince;
  final String beneficiaryDateOfBirth;
  final EntityType beneficiaryIdentificationType;
  final String beneficiaryIdentificationValue;
  final List<PaymentType> paymentTypes;
  final String onBehalfOf;

  CreateBeneficiary({
    @required this.name,
    @required this.bankAccountHolderName,
    @required this.bankCountry,
    @required this.currency,
    this.email,
    this.beneficiaryAddress,
    this.beneficiaryCountry,
    this.accountNumber,
    this.routingCodeType1,
    this.routingCodeValue1,
    this.routingCodeType2,
    this.routingCodeValue2,
    this.bicSwift,
    this.iban,
    this.defaultBeneficiary,
    this.bankAddress,
    this.bankName,
    this.bankAccountType,
    this.beneficiaryEntityType,
    this.beneficiaryCompanyName,
    this.beneficiaryFirstName,
    this.beneficiaryLastName,
    this.beneficiaryCity,
    this.beneficiaryPostcode,
    this.beneficiaryStateOrProvince,
    this.beneficiaryDateOfBirth,
    this.beneficiaryIdentificationType,
    this.beneficiaryIdentificationValue,
    this.paymentTypes,
    this.onBehalfOf,
  });

  factory CreateBeneficiary.fromJson(Map<String, dynamic> json) =>
      _$CreateBeneficiaryFromJson(json);

  Map<String, dynamic> toJson() => _$CreateBeneficiaryToJson(this);
}

@JsonSerializable(fieldRename: FieldRename.snake, includeIfNull: false)
class Beneficiary {
  final String id;
  final String bankAccountHolderName;
  final String name;
  final String email;
  final List<PaymentType> paymentTypes;
  final List<String> beneficiaryAddress;
  final String beneficiaryCountry;
  final EntityType beneficiaryEntityType;
  final String beneficiaryCompanyName;
  final String beneficiaryFirstName;
  final String beneficiaryLastName;
  final String beneficiaryCity;
  final String beneficiaryPostcode;
  final String beneficiaryStateOrProvince;
  final String beneficiaryDateOfBirth;
  final EntityType beneficiaryIdentificationType;
  final String beneficiaryIdentificationValue;
  final String bankCountry;
  final String bankName;
  final List<String> bankAddress;
  final BankAccountType bankAccountType;
  final String onBehalfOf;

  /// Currency code (ISO 4217)
  final String currency;
  final String accountNumber;
  final RoutingCodeType routingCodeType1;
  final String routingCodeValue1;
  final RoutingCodeType routingCodeType2;
  final String routingCodeValue2;
  final String bicSwift;
  final String iban;
  @JsonKey(toJson: boolToJson, fromJson: boolFromJson)
  final bool defaultBeneficiary;
  final String creatorContactId;
  final String beneficiaryExternalReference;
  final DateTime createdAt;
  final DateTime updatedAt;

  Beneficiary({
    @required this.id,
    @required this.bankAccountHolderName,
    @required this.name,
    this.email,
    this.paymentTypes,
    this.beneficiaryAddress,
    this.beneficiaryCountry,
    this.beneficiaryEntityType,
    this.beneficiaryCompanyName,
    this.beneficiaryFirstName,
    this.beneficiaryLastName,
    this.beneficiaryCity,
    this.beneficiaryPostcode,
    this.beneficiaryStateOrProvince,
    this.beneficiaryDateOfBirth,
    this.beneficiaryIdentificationType,
    this.beneficiaryIdentificationValue,
    this.bankCountry,
    this.bankName,
    this.bankAddress,
    this.bankAccountType,
    this.onBehalfOf,
    this.currency,
    this.accountNumber,
    this.routingCodeType1,
    this.routingCodeValue1,
    this.routingCodeType2,
    this.routingCodeValue2,
    this.bicSwift,
    this.iban,
    this.defaultBeneficiary,
    this.creatorContactId,
    this.beneficiaryExternalReference,
    this.createdAt,
    this.updatedAt,
  });

  factory Beneficiary.fromJson(Map<String, dynamic> json) =>
      _$BeneficiaryFromJson(json);

  Map<String, dynamic> toJson() => _$BeneficiaryToJson(this);
}
